==> SemanticWeb-Schema-v14.0.0.tar.gz: SemanticWeb-Schema-v14.0.0/lib/SemanticWeb/Schema/TakeAction.pm <==
use utf8;

package SemanticWeb::Schema::TakeAction;

# ABSTRACT: The act of gaining ownership of an object from an origin

use Moo;

extends qw/ SemanticWeb::Schema::TransferAction /;


use MooX::JSON_LD 'TakeAction';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v14.0.0';




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::TakeAction - The act of gaining ownership of an object from an origin

=head1 VERSION

version v14.0.0

=head1 DESCRIPTION

The act of gaining ownership of an object from an origin. Reciprocal of GiveAction.

Related actions:

=over

=item *

L<SemanticWeb::Schema::GiveAction>: The reciprocal of TakeAction.

=item *

L<SemanticWeb::Schema::ReceiveAction>: Unlike ReceiveAction, TakeAction implies that ownership has been transfered.

=back

=head1 SEE ALSO

L<SemanticWeb::Schema::TransferAction>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2022 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut

==> SemanticWeb-Schema-v15.0.0.tar.gz: SemanticWeb-Schema-v15.0.0/lib/SemanticWeb/Schema/TakeAction.pm <==
use utf8;

package SemanticWeb::Schema::TakeAction;

# ABSTRACT: The act of gaining ownership of an object from an origin

use Moo;

extends qw/ SemanticWeb::Schema::TransferAction /;


use MooX::JSON_LD 'TakeAction';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v15.0.0';




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::TakeAction - The act of gaining ownership of an object from an origin

=head1 VERSION

version v15.0.0

=head1 DESCRIPTION

The act of gaining ownership of an object from an origin. Reciprocal of GiveAction.

Related actions:

=over

=item *

L<SemanticWeb::Schema::GiveAction>: The reciprocal of TakeAction.

=item *

L<SemanticWeb::Schema::ReceiveAction>: Unlike ReceiveAction, TakeAction implies that ownership has been transferred.

=back

=head1 SEE ALSO

L<SemanticWeb::Schema::TransferAction>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2022 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
